<?php

namespace Drupal\flexible_google_cse\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Component\Utility\UrlHelper;
use Drupal\Core\Path\AliasStorage;


/**
 * Class SearchConfig.
 */
class SearchConfig extends ConfigFormBase {


  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'flexible_google_cse_config_form';
  }

    /**
   * {@inheritdoc}
   */
  public function getEditableConfigNames() {
    return ['flexible_google_cse.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    
    $fgsConfig = $this->config('flexible_google_cse.settings');

    $form['gse_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('GSE Key'),
      '#description' => $this->t('Google Custom Search Key'),
      '#maxlength' => 128,
      '#size' => 56,
      '#weight' => '0',
      '#default_value' => $fgsConfig->get('gse_key'),
    ];
    
    //Value of the Search Button
    $form['submit_value'] = array(
      '#type' => 'textfield',
      '#size' => 56,
      '#title' => $this->t('Search Button Value'),
      '#description' => $this->t('Configure Value of the search Button'),
      '#default_value' => $fgsConfig->get('submit_value'),
    );

  // The page to display Result on
    $form['search_url'] = array(
      '#type' => 'textfield',
      '#size' => 56,
      '#title' => $this->t('Search Result URl'),
      '#description' => $this->t('Configure URl to display the search result on followed by /'),
      '#default_value' => $fgsConfig->get('search_url'),
    );

    //Lenght of Search box 
    $form['textbox_size'] = array(
      '#type' => 'number',
      '#title' => $this->t('Search Box size'),
      '#description' => $this->t('Configure the text size of search input box'),
      '#default_value' => $fgsConfig->get('textbox_size'),
    );

    //result display type 
    $form['result_layout'] = array(
      '#type' => 'radios',
      '#title' => $this->t('Search Result Layout'),
      '#options' => array(
        'gcse:search' => t('Result and search Box'),
        'gcse:searchresults-only' =>t('Result Only'),
    ),
  '#default_value' => $fgsConfig->get('result_layout'),
);


    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    
    $values = $form_state->getValues();
    $ResultURl = $values['search_url'];


    //Validate if the Search Result URL start with /
     if(preg_match("/^\\/(.*)/i", trim($ResultURl)))
     {
        parent::validateForm($form, $form_state);
     }
     else
     {
       
      $form_state->setErrorByName('search_url', $this->t('Invalid URL Alias provided. Please fix the issue before proceeding.'));
     }
     
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    
    $values = $form_state->getValues();

    //URL alias for the search result page 

          if($values['search_url']!='/fgcs_search')
        {

              $URLAlias=$this->CreateAlias($values['search_url']);        
        }

    $fgsConfig_Settings = $this->config('flexible_google_cse.settings');
    $fgsConfig_Settings->set('gse_key', $values['gse_key']);
    $fgsConfig_Settings->set('textbox_size', $values['textbox_size']);
    $fgsConfig_Settings->set('submit_value', $values['submit_value']);
    $fgsConfig_Settings->set('search_url', $values['search_url']);
    $fgsConfig_Settings->set('result_layout', $values['result_layout']);

    $fgsConfig_Settings->save();




    parent::submitForm($form, $form_state);


  }
/*
* A function to create A valid URL alias for the search result page 
*/
public function CreateAlias($search_url)
  {
        $path = \Drupal::service('path.alias_storage')->save("/fgs-search", $search_url , "en");
        return $path;
  }


}



